;; Generated package description from pulsar.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "pulsar" "1.4.1.0.20260904.7" "Pulse highlight on demand or after select functions" '((emacs "28.1")) :commit "b82c595ff67b127ea1bcb2a17aa423d72cbbe8c4" :authors '(("Protesilaos" . "info@protesilaos.com")) :maintainer '("Protesilaos" . "info@protesilaos.com") :keywords '("convenience" "pulse" "highlight") :url "https://github.com/protesilaos/pulsar")
